@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020 CERN.
+# Copyright (C) 2020-2021 CERN.
 #
 # Invenio-Cli is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -67,11 +67,29 @@ def install(cli_config, packages, skip_build):
 @pass_cli_config
 def outdated(cli_config):
     """Show outdated Python dependencies."""
-    raise click.UsageError("Not supported yet.")
+    steps = PackagesCommands.outdated_packages()
+
+    on_fail = "Some of the packages need to be updated."
+    on_success = "All packages are up to date."
+
+    run_steps(steps, on_fail, on_success)
 
 
 @packages.command()
+@click.argument("version", required=False, type=str)
 @pass_cli_config
-def update(cli_config):
-    """Update a single Python python package."""
-    raise click.UsageError("Not supported yet.")
+def update(cli_config, version=None):
+    """Update all or some Python python packages."""
+    if version:
+        db = cli_config.get_db_type()
+        es = f"elasticsearch{cli_config.get_es_version()}"
+        package = f"invenio-app-rdm[{db},{es}]~="
+        steps = PackagesCommands.update_package_new_version(package, version)
+        on_fail = f"Failed to update version {version}"
+        on_success = f"Version {version} installed successfully."
+    else:
+        steps = PackagesCommands.update_packages()
+        on_fail = "Failed to update packages."
+        on_success = "Packages installed successfully."
+
+    run_steps(steps, on_fail, on_success)
